@@ -1,5 +1,5 @@
 module UU.Parsing.CharParser where
-
+import GHC.Prim
 import UU.Parsing.Interface
 import UU.Scanner.Position
 
@@ -9,7 +9,7 @@ type CharParser = AnaParser Input Pair Char Pos
 instance Symbol Char where
  symBefore    = pred
  symAfter     = succ
- deleteCost _ = 5
+ deleteCost _ = 5#
 
 data Input = Input String !Pos
 
@@ -28,12 +28,12 @@ instance InputState Input Char Pos where
   splitState  (Input inp pos) =  
         case inp of
           ('\CR':      xs) -> case xs of
-                                ('\LF' : _ ) -> ('\CR', Input xs pos)
-                                _            -> ('\CR', Input xs (newl pos))
-          ('\LF':      xs) -> ( '\LF', Input xs (newl   pos))
+                                ('\LF' : _ ) -> (# '\CR', Input xs pos #)
+                                _            -> (# '\CR', Input xs (newl pos) #)
+          ('\LF':      xs) -> (# '\LF', Input xs (newl   pos) #)
 --          ('\n' :      xs) -> ( '\n' , Input xs (newl   pos)) -- \n already captured above
-          ('\t' :      xs) -> ( '\t' , Input xs (tab    pos))
-          (x    :      xs) -> ( x    , Input xs (advc 1 pos))
+          ('\t' :      xs) -> (# '\t' , Input xs (tab    pos) #)
+          (x    :      xs) -> (# x    , Input xs (advc 1 pos) #)
 
   getPosition (Input inp pos) = pos
 
