@@ -12,6 +12,7 @@ module UU.Parsing.Offside( parseOffside
                          , OffsideParser(..)
                          ) where
                          
+import GHC.Prim
 import UU.Parsing.Interface
 import UU.Parsing.Machine
 import UU.Parsing.Derived(opt, pFoldr1Sep,pList,pList1, pList1Sep)
@@ -74,6 +75,23 @@ scanOffside mod open close triggers ts = start ts []
         -- L  ( {:ts)  ms     = {: (L  ts (0:ms))       (Note  4) 
         -- L  (t:ts)  (m:ms)  = }: (L  (t:ts)  ms)      if  m /= 0  and  parse-error(t) (Note  5) 
         -- L  (t:ts)  ms      = t : (L  ts ms) 
+        sameln tts ms = case splitStateE tts of
+              Left'  t ts  ->
+                        let tail
+                              | isTrigger t  = aftertrigger ts ms
+                              | isClose t    = case ms of
+                                                         0:rs -> layout ts rs
+                                                         _    -> layout ts ms
+
+                              | isOpen t    = layout ts (0:ms)
+                              | otherwise   = layout ts ms
+                            parseError = case ms of
+                                           m:ms  | m /= 0 -> Just (layout tts ms)
+                                           _              -> Nothing
+                        in  Off pos (Cons (Symbol t) tail) parseError
+              Right' rest -> endofinput pos rest ms
+          where pos = getPosition tts
+{-
         sameln tts ms = case splitStateE tts of
                 Left'  t ts  | isTrigger t -> cons pos (Symbol t) (aftertrigger ts ms)
                              | isClose t   -> cons pos (Symbol t) 
@@ -88,6 +106,7 @@ scanOffside mod open close triggers ts = start ts []
                                               in Off pos (Cons (Symbol t) (layout ts ms)) parseError
                 Right' rest -> endofinput pos rest ms
           where pos = getPosition tts                        
+-}
 
         -- L  []  []          = [] 
         -- L  []  (m:ms)      = } : L  []  ms           if m /=0   (Note  6) 
@@ -108,16 +127,16 @@ instance InputState inp s p => InputState (OffsideInput inp s p) (OffsideSymbol
                                      _           -> Right' inp                                 
   splitState (Off _ stream _) = 
            case stream of
-            Cons s rest -> (s ,rest)                        
+            Cons s rest -> (# s ,rest #)                        
 
   getPosition (Off pos _ _ ) = pos
   
 instance Symbol s => Symbol (OffsideSymbol s) where
   deleteCost s = case s of
                   Symbol s   -> deleteCost s
-                  SemiColon  -> 5
-                  OpenBrace  -> 5
-                  CloseBrace -> 5
+                  SemiColon  -> 5#
+                  OpenBrace  -> 5#
+                  CloseBrace -> 5#
   symBefore s = case s of
                  Symbol s   -> Symbol (symBefore s)
                  SemiColon  -> error "Symbol.symBefore SemiColon"
@@ -170,7 +189,7 @@ operatorr f g (OP p) = OP (f g p)
 
 pSeparator :: (OutputState o, InputState i s p, Position p, Symbol s, Ord s) 
            => OffsideParser i o s p ()
-pSeparator = OP (() <$ pCostSym 5 SemiColon SemiColon)
+pSeparator = OP (() <$ pCostSym 5# SemiColon SemiColon)
 
 pClose, pOpen :: (OutputState o, InputState i s p, Position p, Symbol s, Ord s) 
            => OffsideParser i o s p ()
@@ -217,11 +236,19 @@ pBlock1 :: (InputState i s p, OutputState o, Position p, Symbol s, Ord s)
        -> OffsideParser i o s p z 
        -> OffsideParser i o s p a 
        -> OffsideParser i o s p [a]
+pBlock1 open sep close p =  pOffside open close explicit implicit
+ where elem = (:) <$> p `opt` id
+       sep' = () <$ sep
+       elems s = (:) <$ pList s <*> p <*> (($[]) <$> pFoldr1Sep ((.),id) s elem)
+       explicit = elems sep'
+       implicit = elems (sep' <|> pSeparator)
+{-
 pBlock1 open sep close p =  pOffside open close explicit implicit
  where sep'    = () <$ sep
        elems s = pList s *> pList1Sep (pList1 s) p <* pList s
        explicit = elems sep'
        implicit = elems (sep' <|> pSeparator)
+-}
 
 parseOffside :: (Symbol s, InputState i s p, Position p) 
              => OffsideParser i Pair s p a 
